#!/bin/sh
#
# E.S.O. - VLT project/ESO Archive
# $Id: skycat.sh.in,v 1.1.1.1 2002/04/04 20:11:53 brighton Exp $ 
#
# skycat.sh.in - This script is used to start Tcl/Tk applications
#
# To install a Tcl/Tk script, make a soft link to this file
# in the same directory. This script will determine
# the name of the Tcl source file to load based on the name
# of the link and the environment variables.
#
# Note: this file is processed with configure to set path variables.
#
# See man page for a complete description.
#
# who         when       what
# --------   ---------   ----------------------------------------------
# A.Brighton 24 Oct 95   created
#

# set basic shared library runtime search path (see also below)
LD_LIBRARY_PATH="/root/sources/skycat-2.7.3/../install/lib:/vlt/APR2004/tcltk/lib:/vlt/APR2004/tcltk/lib/itcl:/usr/X11R6/lib:${LD_LIBRARY_PATH}"

# when running from the source dir, set different env for local test
test -f ../demos/skycat_env.sh && . ../demos/skycat_env.sh

# During development, set CAT_LIBRARY to your local cat/tclcat/library
# directory, otherwise the tcl/tk scripts are taken from the installed
# versions
if [ -z "$CAT_LIBRARY" ]
then
  # use the installed Tcl/Tk files and shared library
  CAT_LIBRARY=${INSTALL_TARGET}/lib/cat; export CAT_LIBRARY
else
  # use the local development Tcl/Tk files and shared library
  LD_LIBRARY_PATH="$CAT_LIBRARY/../..:${LD_LIBRARY_PATH}"
fi

# During development, set RTD_LIBRARY to your local rtd/rtdimg/library
# directory, otherwise the tcl/tk scripts are taken from the installed
# versions
if [ -z "$RTD_LIBRARY" ]
then
  # use the installed Tcl/Tk files and shared library
  RTD_LIBRARY=${INSTALL_TARGET}/lib/rtd; export RTD_LIBRARY
else
  # use the local development Tcl/Tk files and shared library
  LD_LIBRARY_PATH="$RTD_LIBRARY/../..:${LD_LIBRARY_PATH}"
fi

# During development, set SKYCAT_LIBRARY to your local skycat/interp/library
# directory, otherwise the tcl/tk scripts are taken from the installed
# versions
if [ -z "$SKYCAT_LIBRARY" ]
then
  # use the installed Tcl/Tk files and shared library
  SKYCAT_LIBRARY=/root/sources/skycat-2.7.3/../install/lib/skycat; export SKYCAT_LIBRARY
else
  # use the local development Tcl/Tk files and shared library
  LD_LIBRARY_PATH="$SKYCAT_LIBRARY/../..:${LD_LIBRARY_PATH}"
fi

# name of program to run
prog=`basename $0`

# wish binary to use
WISH=$SKYCAT_LIBRARY/../bin/skycat_wish
test -f $WISH || WISH=$SKYCAT_LIBRARY/../../bin/skycat_wish

# set environment variables for packages
if [ -d "/vlt/APR2004/tcltk/lib/tcl8.4" ]
then
  TCL_LIBRARY=/vlt/APR2004/tcltk/lib/tcl8.4
  export TCL_LIBRARY
fi
 
if [ -d "/vlt/APR2004/tcltk/lib/tk8.4" ]
then
  TK_LIBRARY=/vlt/APR2004/tcltk/lib/tk8.4
  export TK_LIBRARY
fi
 
if [ -d "/vlt/APR2004/tcltk/lib/blt2.4" ]
then
  BLT_LIBRARY=/vlt/APR2004/tcltk/lib/blt2.4
  export BLT_LIBRARY
fi

# start an interactive shell
if [ "$prog" = "skycat.sh" ]
then exec $WISH
fi

# determine which tcl file to start
file=$SKYCAT_LIBRARY/demos/$prog.tcl

# be careful about passing arguments with embedded spaces
if [ "$#" = "0" ]
then
    exec $WISH -f $file
fi

exec $WISH -f $file "$@"
